@@ -21,7 +21,7 @@ def _with_json(f):
     @wraps(f)
     def wrapper(self, json_string, *args, **kwargs):
         return json.dumps(
-            f(self, load_json(json_string), *args, **kwargs))
+            f(self, load_json(json_string), *args, **kwargs), ensure_ascii=False)
     return wrapper
 
 
@@ -35,7 +35,7 @@ class HTTP:
     Pointer, go to http://tools.ietf.org/html/draft-pbryan-zyp-json-pointer-00.
     """
 
-    ROBOT_LIBRARY_VERSION = "0.4.1"
+    ROBOT_LIBRARY_VERSION = "0.4.2"
 
     class Context(object):
         def __init__(self, http, host=None, scheme='http'):
@@ -547,7 +547,7 @@ class HTTP:
         """
 
         try:
-            return json.dumps(data)
+            return json.dumps(data, ensure_ascii=False)
         except ValueError, e:
             raise ValueError(
                 "Could not stringify '%r' to JSON: %s" % (data, e))
@@ -618,7 +618,7 @@ class HTTP:
         """
         Logs a pretty printed version of the JSON document `json_string`.
         """
-        for line in json.dumps(json_string, indent=2).split('\n'):
+        for line in json.dumps(json_string, indent=2, ensure_ascii=False).split('\n'):
             logger.write(line, log_level)
 
     # debug
